@@ -3,7 +3,7 @@ package App::perlimports::Document;
 use Moo;
 use utf8;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000016';
 
 use App::perlimports::Annotations ();
 use App::perlimports::Include     ();
@@ -505,6 +505,12 @@ sub _extract_symbols_from_snippet {
 
     my $casts = $doc->find('PPI::Token::Cast') || [];
     for my $cast ( @{$casts} ) {
+
+        # Optimistically avoid misinterpreting regex assertions as casts
+        # We don't want to match on "A" in the following example:
+        # if ( $thing =~ m{ \A b }x ) { ... }
+        next if $cast eq '\\';
+
         my $full_cast   = $cast . $cast->snext_sibling;
         my $cast_as_doc = PPI::Document->new( \$full_cast );
         push @symbols,
@@ -708,18 +714,22 @@ sub _is_used_fully_qualified {
 
     # We could tighten this up and check that the word following "::" is a sub
     # which exists in that package.
+    #
+    # Module::function
+    # Module::->new
+    # isa => ArrayRef[Module::]
     return 1 if $self->ppi_document->find(
         sub {
             (
                 $_[1]->isa('PPI::Token::Word')
                     && (
-                    $_[1]->content =~ m{\A${module_name}::[a-zA-Z_]}
+                    $_[1]->content =~ m{\A${module_name}::[a-zA-Z0-9_]*\z}
                     || (   $_[1]->content eq ${module_name}
                         && $_[1]->snext_sibling eq '->' )
                     )
                 )
                 || ( $_[1]->isa('PPI::Token::Symbol')
-                && $_[1] =~ m{\A[*\$\@\%]+${module_name}::[a-zA-Z_]} );
+                && $_[1] =~ m{\A[*\$\@\%]+${module_name}::[a-zA-Z0-9_]} );
         }
     );
 
@@ -972,7 +982,7 @@ App::perlimports::Document - Make implicit imports explicit
 
 =head1 VERSION
 
-version 0.000015
+version 0.000016
 
 =head2 inspector_for( $module_name )
 
